AeadEncryptor

Struct AeadEncryptor 

pub struct AeadEncryptor { /* private fields */ }
AEAD_AES_256_CBC_HMAC_SHA256 encryption context.

Provides encryption and decryption operations for Always Encrypted data.

Implementations

Source

impl AeadEncryptor

pub fn new(cek: &[u8]) -> Result<Self, EncryptionError>

Create a new encryptor from a Column Encryption Key.

Arguments
  • cek - The Column Encryption Key (32 bytes)
Errors

Returns an error if key derivation fails.

pub fn encrypt( &self, plaintext: &[u8], encryption_type: EncryptionType, ) -> Result<Vec<u8>, EncryptionError>

Encrypt plaintext using AEAD_AES_256_CBC_HMAC_SHA256.

Arguments
  • plaintext - The data to encrypt
  • encryption_type - Randomized or Deterministic encryption
Returns

The ciphertext in the format: version_byte + MAC + IV + aes_ciphertext

Errors

Returns an error if encryption fails.

pub fn decrypt(&self, ciphertext: &[u8]) -> Result<Vec<u8>, EncryptionError>

Decrypt ciphertext using AEAD_AES_256_CBC_HMAC_SHA256.

Arguments
  • ciphertext - The encrypted data (version + MAC + IV + aes_ciphertext)
Returns

The decrypted plaintext.

Errors

Returns an error if:

  • Ciphertext is too short
  • Version byte is invalid
  • MAC verification fails (data may be tampered)
  • Decryption fails