pub struct SecretString(/* private fields */);Expand description
A secret string that is securely zeroed from memory when dropped.
This type is only available when the zeroize feature is enabled.
It ensures that sensitive data like passwords and tokens are overwritten
with zeros when they go out of scope.
Implementations