AuthError

Enum AuthError 

#[non_exhaustive]
pub enum AuthError { InvalidCredentials(String), AuthenticationFailed(String), TokenExpired, TokenAcquisition(String), UnsupportedMethod(String), Sspi(String), Certificate(String), Network(String), Configuration(String), AzureIdentity(String), }
Errors that can occur during authentication.

Variants (Non-exhaustive)

This enum is marked as non-exhaustive
Non-exhaustive enums could have additional variants added in future. Therefore, when matching against variants of non-exhaustive enums, an extra wildcard arm must be added to account for any future variants.


InvalidCredentials(String)

Invalid credentials provided.



AuthenticationFailed(String)

Authentication failed on server.



TokenExpired

Token expired or invalid.



TokenAcquisition(String)

Token acquisition failed.



UnsupportedMethod(String)

Unsupported authentication method.



Sspi(String)

SSPI/GSSAPI error.



Certificate(String)

Certificate error.



Network(String)

Network error during authentication.



Configuration(String)

Configuration error.



AzureIdentity(String)

Azure identity error.

Implementations

Source

impl AuthError

pub fn is_transient(&self) -> bool

Check if this error is transient and may succeed on retry.

Network errors, token acquisition failures (may be temporary service issues), and Azure identity errors are potentially transient. Invalid credentials and unsupported methods are terminal.

pub fn is_terminal(&self) -> bool

Check if this error is terminal and will never succeed on retry.

Invalid credentials, unsupported methods, certificate errors, and configuration errors are permanent.